@@ -4,7 +4,7 @@ use log::Level;
 /// LogAppender append logs
 /// Appender will be running on single main thread,please do_log for new thread or new an Future
 pub trait LogAppender: Send {
-    fn do_log(&self, record: &mut [FastLogRecord]);
+    fn do_log(&self, record: &mut FastLogRecord);
 
     fn type_name(&self) -> &'static str {
         std::any::type_name::<Self>()
